@@ -1,11 +1,12 @@
 """Asynchronous Python client for the Ambee API."""
 
-from .ambee import Ambee, AmbeeConnectionError, AmbeeError
+from .ambee import Ambee, AmbeeAuthenticationError, AmbeeConnectionError, AmbeeError
 from .models import AirQuality  # noqa
 
 __all__ = [
     "AirQuality",
     "Ambee",
+    "AmbeeAuthenticationError",
     "AmbeeConnectionError",
     "AmbeeError",
 ]
